# Welcome to qual_gis


[![image](https://img.shields.io/pypi/v/qual_gis.svg)](https://pypi.python.org/pypi/qual_gis)


**Qualitative GIS tools**


-   Free software: MIT License
-   Documentation: <https://fschrupprivero.github.io/qual_gis>
    

## Features

-   TODO
